@@ -212,10 +212,9 @@ void xs_configure_ok(void)
 	/* STIL and miscellaneous settings */	
 	xs_cfg.detectMagic = GTK_TOGGLE_BUTTON(cfg_checkfilecontent)->active;
 	xs_cfg.usestil = GTK_TOGGLE_BUTTON(cfg_stil_use)->active;
-	if (xs_cfg.stilpath != NULL) g_free(xs_cfg.stilpath);
-	xs_cfg.stilpath = gtk_entry_get_text(GTK_ENTRY(cfg_stil_path)); 
-	if (xs_cfg.fileInfo != NULL) g_free(xs_cfg.fileInfo);
-	xs_cfg.fileInfo = gtk_entry_get_text(GTK_ENTRY(cfg_songnameformat)); 
+
+	xs_strcalloc(&xs_cfg.stilpath, gtk_entry_get_text(GTK_ENTRY(cfg_stil_path)));
+	xs_strcalloc(&xs_cfg.fileInfo, gtk_entry_get_text(GTK_ENTRY(cfg_songnameformat)));
 		
 
 	/* Try to open the XMMS configuration file */
